# -*- coding: utf-8 -*-

class DB:
  """This class handle mostly database management stuffs"""
  def __init__(self):
    pass

  def make_migrations(self):
    pass

  def migrating_database(self):
    pass

  def update_db(self):
    pass

  def dump_db(self):
    pass

  def cleaned_db(self):
    pass

"""
Command line shortcuts for database:
  db_status
  db_migrate
  db_makemigrations
  db_pulldata
  db_pushdata
  db_cleaned
"""
